@@ -1,6 +1,6 @@
 package Bio::Tools::Run::QCons::Types;
 {
-  $Bio::Tools::Run::QCons::Types::VERSION = '0.112880';
+  $Bio::Tools::Run::QCons::Types::VERSION = '0.112881';
 }
 
 # ABSTRACT: Type library for Bio::Tools::Run::QCons
@@ -11,7 +11,7 @@ use warnings;
 use Mouse::Util::TypeConstraints;
 use namespace::autoclean;
 
-use File::Which;
+use IPC::Cmd qw(can_run);
 
 subtype 'Executable'
     => as 'Str',
@@ -23,7 +23,7 @@ sub _exists_executable {
 
     return 1 if -x $candidate;
 
-    return scalar which($candidate);
+    return scalar can_run($candidate);
 }
 
 no Mouse::Util::TypeConstraints;
@@ -37,7 +37,7 @@ Bio::Tools::Run::QCons::Types - Type library for Bio::Tools::Run::QCons
 
 =head1 VERSION
 
-version 0.112880
+version 0.112881
 
 =head1 AUTHOR
 
